@@ -1,6 +1,6 @@
 # coding=utf-8
 # pystray
-# Copyright (C) 2016-2020 Moses Palmér
+# Copyright (C) 2016-2022 Moses Palmér
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -30,6 +30,11 @@ from pystray import _base
 from . import notify_dbus
 
 
+# Make sure Gtk works
+if not Gtk.init_check()[0]:
+   raise ImportError('Gtk could not be initialised')
+
+
 def mainloop(f):
     """Marks a function to be executed in the main loop.
 
